from __future__ import print_function
import pytest
from virgotools.gpstime import *
from virgotools import gpstime
import numpy as np
import datetime

from virgotools.virgo_logging import log_to_console
log_to_console('DEBUG')  # FIXME: I do not see debugging output with py.test -s


def test_roundtrip():
    print()
    for g in np.linspace(0, now_gps(), 20).round():
        print('Testing utc2gps(gps2utc(g)) == g for', gps2str(g))
        assert utc2gps(gps2utc(g)) == g  # might not be true for leap-seconds


def test_GW150914():
    # see https://losc.ligo.org/events/GW150914/
    assert utc2gps(2015, 9, 14, 9, 50, 45) == 1126259462


def test_now():
    assert abs(lt2gps(datetime.datetime.now()) - now_gps()) < 0.5


def test_bounds():
    with pytest.raises(ValueError):
        utc2gps(datetime.datetime(1971, 12, 30))

    # test that conversion works after expiration day, and that no leap-second
    # is introduced
    day = datetime.timedelta(days=1)
    t_expire = gpstime.leap_info.t_expire
    assert (utc2gps(t_expire + day) - utc2gps(t_expire - day) ==
        2 * 86400)
